@@ -11,9 +11,9 @@ newPVMnode <- function(where = "",
     homogeneous <- getClusterOption("homogeneous", options)
     if (getClusterOption("useRscript", options)) {
         if (homogeneous) {
-            rscript <- getClusterOption("rscript", options)
+            rscript <- shQuoteIfNeeded(getClusterOption("rscript", options))
             snowlib <- getClusterOption("snowlib", options)
-            script <- file.path(snowlib, "snow", "RPVMnode.R")
+            script <- shQuoteIfNeeded(file.path(snowlib, "snow", "RPVMnode.R"))
             args <- c(script,
                       paste("SNOWLIB=", snowlib, sep=""),
                       paste("OUT=", outfile, sep=""))
@@ -27,9 +27,9 @@ newPVMnode <- function(where = "",
     }
     else {
         if (homogeneous) {
-            script <- file.path(scriptdir, "RPVMnode.sh")
+            script <- shQuoteIfNeeded(file.path(scriptdir, "RPVMnode.sh"))
             rlibs <- paste(getClusterOption("rlibs", options), collapse = ":")
-            rprog <- getClusterOption("rprog", options)
+            rprog <- shQuoteIfNeeded(getClusterOption("rprog", options))
             args <- c(paste("RPROG=", rprog, sep=""),
                       paste("OUT=", outfile, sep=""),
                       paste("R_LIBS=", rlibs, sep=""),
